py-aem manual | 1. Introduction

#

## 1. Introduction

### About AEM

The `aem` package implements a mid-level object-oriented wrapper around the low-level Carbon Apple Event Manager APIs. It provides the following services:

- an object-oriented API for constructing Apple Event Object Model queries ("references")
- data conversion between common Python and Apple event types
- AEAddressDesc creation
- Apple event construction and dispatch.

AEM provides a direct foundation for the high-level appscript package. It can also be used directly by developers and end-users for controlling scriptable applications in situations where appscript is unavailable or unsuitable.

Note that this documentation is an API reference, not a full user guide. Some familiarity with Apple events and the Apple Event Manager is required in order to understand and use AEM.